import './index.css';
import nameGenerator from './name-generator';
import isDef from './is-def';
import {Temperature, TimeSeries, OnOff, Percent} from './objectModel.js';



// Store/retrieve the name in/from a cookie.
const cookies = document.cookie.split(';');
//console.log(cookies)
let wsname = cookies.find(function(c) {
  if (c.match(/wsname/) !== null) return true;
  return false;
});
if (isDef(wsname)) {
  wsname = wsname.split('=')[1];
} else {
  wsname = nameGenerator();
  document.cookie = "wsname=" + encodeURIComponent(wsname);
}

// Set the name in the header
document.querySelector('header>p').textContent = "Liste des capteurs";

// Create a WebSocket connection to the server
const ws = new WebSocket("ws://" + window.location.host+ "/socket");

// We get notified once connected to the server
ws.onopen = (event) => {
  console.log("We are connected.");
};

const mqtt = require('mqtt')
const client = mqtt.connect('ws://127.0.0.1:1234');
var arraySensors = [];

client.on('connect', () => {
  client.subscribe('value/#');
})

client.on('message', (topic, message) => {

  var name = topic.substring(6);
  var obj = JSON.parse(message);
  var value = obj["value"];
  var type = obj["type"];

  switch(type){
    case 'TEMPERATURE':
      if (arraySensors[name] === undefined) {
        //console.log("creation");
        arraySensors[name] = new Temperature(name, type, new TimeSeries(value, Date()));
      }else{
        //console.log("existe deja ");
        arraySensors[name]._data.add(value, Date());
      }
    break;

    case 'ON_OFF':
      if (arraySensors[name] === undefined) {
        //console.log("creation");
        arraySensors[name] = new OnOff(name, type, new TimeSeries(value, Date()));
      }else{
        //console.log("existe deja ");
        arraySensors[name]._data.add(value, Date());
      }
    break;

    case 'PERCENT':
      if (arraySensors[name] === undefined) {
        //console.log("creation");
        arraySensors[name] = new Percent(name, type, new TimeSeries(value, Date()));
      }else{
        //console.log("existe deja ");
        arraySensors[name]._data.add(value, Date());
      }
    break;
    default:

  }

  var s = "";
  for(var sensor in arraySensors){
    s+="<li><h3> Capteurs : "+arraySensors[sensor]._id+"</h3><br />";
    s+="Type : "+ arraySensors[sensor]._name+"<br />";
    if(arraySensors[sensor]._name!=="ON_OFF"){
      s+="Valeur moyenne : "+arraySensors[sensor]._data.meanOfAllValues()+"<br />";
    }
    var nb = arraySensors[sensor]._data._nbValues;
    if(nb>3){
      s+="3 Dernières valuers : <br />";
      for (var i = nb; i > nb-3; i--) {
        s+="&nbsp;->&nbsp;Label : "+arraySensors[sensor]._data._labels[i-1]+"<br />";
        s+="&nbsp;&nbsp;&nbsp;&nbsp;Value : "+arraySensors[sensor]._data._values[i-1]+"<br />";
      }
    }else{
      for( i = 0; i < nb; i++){
        s+="->&nbsp;Label : "+arraySensors[sensor]._data._labels[i]+"<br />";
        s+="&nbsp;&nbsp;&nbsp;&nbsp;Value : "+arraySensors[sensor]._data._values[i]+"<br />";
      }
    }
    s+="</li>";
  }
  document.getElementById('messages').innerHTML = s;

})
